@@ -12,7 +12,7 @@ import (
 
 	"github.com/stretchr/testify/assert"
 
-	"github.com/evilmartians/lefthook/internal/version"
+	"github.com/evilmartians/lefthook/v2/internal/version"
 )
 
 func TestUpdater_SelfUpdate(t *testing.T) {
@@ -100,7 +100,7 @@ func TestUpdater_SelfUpdate(t *testing.T) {
 			assert := assert.New(t)
 			file, err := os.Create(tt.opts.ExePath)
 			assert.NoError(err)
-			file.Close()
+			assert.NoError(file.Close())
 
 			checksumServer := httptest.NewServer(
 				http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
